Leaflet Draw Build Helper

# Leaflet Build Helper

Select All | Deselect All

## Building using Node and UglifyJS

1. Download and install Node
2. Run this in the command line:

       npm install -g jake
       npm install

3. Run this command inside the Leaflet directory:

## Building using Closure Compiler

1. Download Closure Compiler, extract it into `closure-compiler` directory
2. Run this command in the root Leaflet directory: